@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -93,8 +93,9 @@ public class Change extends ChangeCore {
 
         final Set<String> capabilitiesToAdd = parseAndSetCapabilitiesToAdd(parser);
         final Set<String> capabilitiesToRemove = parseAndSetCapabilitiesToRemove(parser);
-        if ((null != capabilitiesToAdd && !capabilitiesToAdd.isEmpty()) || (null != capabilitiesToRemove && !capabilitiesToRemove.isEmpty())) {
-            oxusr.changeCapabilities(ctx, usr, capabilitiesToAdd, capabilitiesToRemove, auth);
+        final Set<String> capabilitiesToDrop = parseAndSetCapabilitiesToDrop(parser);
+        if ((null != capabilitiesToAdd && !capabilitiesToAdd.isEmpty()) || (null != capabilitiesToRemove && !capabilitiesToRemove.isEmpty()) || (null != capabilitiesToDrop && !capabilitiesToDrop.isEmpty())) {
+            oxusr.changeCapabilities(ctx, usr, capabilitiesToAdd, capabilitiesToRemove, capabilitiesToDrop, auth);
         }
     }
 
@@ -103,5 +104,6 @@ public class Change extends ChangeCore {
         setAddAccessRightCombinationNameOption(parser);
         setCapsToAdd(parser);
         setCapsToRemove(parser);
+        setCapsToDrop(parser);
     }
 }
