@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -156,7 +156,7 @@ public class Context extends ExtendableDataObject implements NameAndIdObject {
     }
 
     public final String getIdAsString() {
-        return String.valueOf(this.id);
+        return null == id ? null : id.toString();
     }
 
     @Override
@@ -191,23 +191,36 @@ public class Context extends ExtendableDataObject implements NameAndIdObject {
      * Add a single login mapping entry.
      */
     public final void addLoginMapping(final String mapping) {
+        if (null == mapping) {
+            return;
+        }
         if (this.login_mappings == null) {
-            this.login_mappings = new HashSet<String>();
+            this.login_mappings = new HashSet<String>(4);
         }
         this.login_mappings.add(mapping);
     }
 
     public final void addLoginMappings(final Collection<String> mapping) {
+        if (null == mapping) {
+            return;
+        }
         if (this.login_mappings == null) {
-            this.login_mappings = new HashSet<String>();
+            this.login_mappings = new HashSet<String>(4);
+        }
+        for (final String sMapping : mapping) {
+            if (null != sMapping) {
+                this.login_mappings.add(sMapping);
+            }
         }
-        this.login_mappings.addAll(mapping);
     }
 
     /*
      * Remove a login mapping.
      */
     public final boolean removeLoginMapping(final String mapping) {
+        if (null == mapping) {
+            return false;
+        }
         if (null != this.login_mappings) {
             return this.login_mappings.remove(mapping);
         } else {
@@ -216,6 +229,9 @@ public class Context extends ExtendableDataObject implements NameAndIdObject {
     }
 
     public final boolean removeLoginMappings(final Collection<String> mapping) {
+        if (null == mapping) {
+            return false;
+        }
         if (null != this.login_mappings) {
             return this.login_mappings.removeAll(mapping);
         } else {
@@ -402,7 +418,7 @@ public class Context extends ExtendableDataObject implements NameAndIdObject {
     public String[] getMandatoryMembersRegister() {
         return null;
     }
-    
+
     /**
      * Gets the quotas
      * <pre>
@@ -414,7 +430,7 @@ public class Context extends ExtendableDataObject implements NameAndIdObject {
     public List<Object[]> getQuotas() {
         return Collections.unmodifiableList(quotas);
     }
-    
+
     /**
      * Sets the quotas
      * <pre>
