@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -103,8 +103,10 @@ public class CreateInfostoreTables extends AbstractCreateTableImpl {
       + "`file_mimetype` varchar(255) ,"
       + "`file_md5sum` varchar(32)  ,"
       + "`file_version_comment` text,"
+      + "`meta` BLOB default NULL,"
       + "PRIMARY KEY (`cid`,`infostore_id`,`version_number`),"
-      + "FOREIGN KEY (cid, infostore_id) REFERENCES infostore (cid, id)"
+      + "FOREIGN KEY (cid, infostore_id) REFERENCES infostore (cid, id),"
+      + "INDEX `md5sumIndex` (`cid`, `file_md5sum`)"
     + ") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";
 
     private static final String createDelInfostoreTable = "CREATE TABLE `del_infostore` ("
@@ -140,7 +142,9 @@ public class CreateInfostoreTables extends AbstractCreateTableImpl {
       + "`file_mimetype` varchar(255) ,"
       + "`file_md5sum` varchar(32) ,"
       + "`file_version_comment` text ,"
-      + "PRIMARY KEY (`cid`,`infostore_id`,`version_number`)"
+      + "`meta` BLOB default NULL,"
+      + "PRIMARY KEY (`cid`,`infostore_id`,`version_number`),"
+      + "INDEX `md5sumIndex` (`cid`, `file_md5sum`)"
     + ") ENGINE=InnoDB DEFAULT CHARSET=utf8 COLLATE=utf8_unicode_ci;";
 
     private static final String createInfostorePropertyTable = "CREATE TABLE `infostore_property` ("
