@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -224,7 +224,7 @@ public class CreateVirtualFolderTables extends AbstractCreateTableImpl {
     @Override
     protected String[] getCreateStatements() {
         return new String[] {
-            CREATE_VIRTUAL_TREE, CREATE_VIRTUAL_PERMISSION, CREATE_VIRTUAL_TREE, CREATE_VIRTUAL_SUBSCRIPTION,
+            CREATE_VIRTUAL_TREE, CREATE_VIRTUAL_PERMISSION, CREATE_VIRTUAL_SUBSCRIPTION,
             CREATE_VIRTUAL_BACKUP_TREE, CREATE_VIRTUAL_BACKUP_PERMISSION, CREATE_VIRTUAL_BACKUP_SUBSCRIPTION };
     }
 }
