@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2012 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2014 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -51,7 +51,6 @@ package com.openexchange.admin.storage.sqlStorage;
 
 import java.sql.Connection;
 import java.sql.SQLException;
-import org.slf4j.Logger;
 import com.openexchange.admin.rmi.exceptions.PoolException;
 import com.openexchange.database.Assignment;
 import com.openexchange.database.DatabaseService;
@@ -108,6 +107,18 @@ public class OXAdminPoolDBPool implements OXAdminPoolInterface {
         return con;
     }
 
+    @Override
+    public Connection getConnection(int poolId, String schema) throws PoolException {
+        final Connection con;
+        try {
+            con = getService().get(poolId, schema);
+        } catch (OXException e) {
+            log.error("Error pickup context database write connection from pool!", e);
+            throw new PoolException(e.getMessage());
+        }
+        return con;
+    }
+
     @Override
     public Connection getConnectionForContextNoTimeout(int contextId) throws PoolException {
         final Connection con;
@@ -180,6 +191,21 @@ public class OXAdminPoolDBPool implements OXAdminPoolInterface {
         return true;
     }
 
+    @Override
+    public boolean pushConnection(int poolId, Connection con) throws PoolException {
+        try {
+            if (null != con && !con.getAutoCommit() && !con.isClosed()) {
+                con.setAutoCommit(true);
+            }
+        } catch (SQLException e) {
+            log.error("Error pushing context database write connection to pool!", e);
+            throw new PoolException(e.getMessage());
+        } finally {
+            getService().back(poolId, con);
+        }
+        return true;
+    }
+
     @Override
     public int getServerId() throws PoolException {
         final int serverId;
@@ -201,4 +227,84 @@ public class OXAdminPoolDBPool implements OXAdminPoolInterface {
             throw new PoolException(e.getMessage());
         }
     }
+
+    @Override
+    public void deleteAssignment(Connection con, int contextId) throws PoolException {
+        try {
+            getService().deleteAssignment(con, contextId);
+        } catch (OXException e) {
+            log.error("Error deleting a context to database assigment.", e);
+            throw new PoolException(e.getMessage());
+        }
+    }
+
+    @Override
+    public int[] getContextInSameSchema(Connection con, int contextId) throws PoolException {
+        try {
+            return getService().getContextsInSameSchema(con, contextId);
+        } catch (OXException e) {
+            log.error("Error getting all contexts from the same schema.", e);
+            throw new PoolException(e.getMessage());
+        }
+    }
+
+    @Override
+    public int[] getContextInSchema(Connection con, int poolId, String schema) throws PoolException {
+        try {
+            return getService().getContextsInSchema(con, poolId, schema);
+        } catch (OXException e) {
+            log.error("Error getting all contexts from the same schema.", e);
+            throw new PoolException(e.getMessage());
+        }
+    }
+
+    @Override
+    public int[] listContexts(int poolId) throws PoolException {
+        try {
+            return getService().listContexts(poolId);
+        } catch (OXException e) {
+            log.error("Error getting all contexts from the same schema.", e);
+            throw new PoolException(e.getMessage());
+        }
+    }
+
+    @Override
+    public String[] getUnfilledSchemas(Connection con, int poolId, int maxContexts) throws PoolException {
+        try {
+            return getService().getUnfilledSchemas(con, poolId, maxContexts);
+        } catch (OXException e) {
+            log.error("Error getting unfilled schemas", e);
+            throw new PoolException(e.getMessage());
+        }
+    }
+
+    @Override
+    public int getWritePool(int contextId) throws PoolException {
+        try {
+            return getService().getWritablePool(contextId);
+        } catch (OXException e) {
+            log.error("Error getting the write pool identifier for context " + contextId + ".", e);
+            throw new PoolException(e.getMessage());
+        }
+    }
+
+    @Override
+    public String getSchemaName(int contextId) throws PoolException {
+        try {
+            return getService().getSchemaName(contextId);
+        } catch (OXException e) {
+            log.error("Error getting the schema name for context " + contextId + ".", e);
+            throw new PoolException(e.getMessage());
+        }
+    }
+
+    @Override
+    public void lock(Connection con) throws PoolException {
+        try {
+            getService().lock(con);
+        } catch (OXException e) {
+            log.error("Error locking context_server2db_pool table", e);
+            throw new PoolException(e.getMessage());
+        }
+    }
 }
